==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkPlane.java <==
// java wrapper for vtkPlane object
//

package vtk;
import vtk.*;

public class vtkPlane extends vtkImplicitFunction
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void EvaluateFunction_2(vtkDataArray id0,vtkDataArray id1);
  public void EvaluateFunction(vtkDataArray id0,vtkDataArray id1)
    { EvaluateFunction_2(id0,id1); }

  private native double EvaluateFunction_3(double id0[]);
  public double EvaluateFunction(double id0[])
    { return EvaluateFunction_3(id0); }

  private native void EvaluateGradient_4(double id0[],double id1[]);
  public void EvaluateGradient(double id0[],double id1[])
    { EvaluateGradient_4(id0,id1); }

  private native void SetNormal_5(double id0,double id1,double id2);
  public void SetNormal(double id0,double id1,double id2)
    { SetNormal_5(id0,id1,id2); }

  private native void SetNormal_6(double id0[]);
  public void SetNormal(double id0[])
    { SetNormal_6(id0); }

  private native double[] GetNormal_7();
  public double[] GetNormal()
    { return GetNormal_7(); }

  private native void SetOrigin_8(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_8(id0,id1,id2); }

  private native void SetOrigin_9(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_9(id0); }

  private native double[] GetOrigin_10();
  public double[] GetOrigin()
    { return GetOrigin_10(); }

  private native void Push_11(double id0);
  public void Push(double id0)
    { Push_11(id0); }

  private native void ProjectPoint_12(double id0[],double id1[],double id2[],double id3[]);
  public void ProjectPoint(double id0[],double id1[],double id2[],double id3[])
    { ProjectPoint_12(id0,id1,id2,id3); }

  private native void ProjectPoint_13(double id0[],double id1[]);
  public void ProjectPoint(double id0[],double id1[])
    { ProjectPoint_13(id0,id1); }

  private native void ProjectVector_14(double id0[],double id1[],double id2[],double id3[]);
  public void ProjectVector(double id0[],double id1[],double id2[],double id3[])
    { ProjectVector_14(id0,id1,id2,id3); }

  private native void ProjectVector_15(double id0[],double id1[]);
  public void ProjectVector(double id0[],double id1[])
    { ProjectVector_15(id0,id1); }

  private native void GeneralizedProjectPoint_16(double id0[],double id1[],double id2[],double id3[]);
  public void GeneralizedProjectPoint(double id0[],double id1[],double id2[],double id3[])
    { GeneralizedProjectPoint_16(id0,id1,id2,id3); }

  private native void GeneralizedProjectPoint_17(double id0[],double id1[]);
  public void GeneralizedProjectPoint(double id0[],double id1[])
    { GeneralizedProjectPoint_17(id0,id1); }

  private native double Evaluate_18(double id0[],double id1[],double id2[]);
  public double Evaluate(double id0[],double id1[],double id2[])
    { return Evaluate_18(id0,id1,id2); }

  private native double DistanceToPlane_19(double id0[],double id1[],double id2[]);
  public double DistanceToPlane(double id0[],double id1[],double id2[])
    { return DistanceToPlane_19(id0,id1,id2); }

  private native double DistanceToPlane_20(double id0[]);
  public double DistanceToPlane(double id0[])
    { return DistanceToPlane_20(id0); }

  private native double EvaluateFunction_21(double id0,double id1,double id2);
  public double EvaluateFunction(double id0,double id1,double id2)
    { return EvaluateFunction_21(id0,id1,id2); }

  public vtkPlane() { super(); }

  public vtkPlane(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkPlane.java <==
// java wrapper for vtkPlane object
//

package vtk;
import vtk.*;

public class vtkPlane extends vtkImplicitFunction
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void EvaluateFunction_2(vtkDataArray id0,vtkDataArray id1);
  public void EvaluateFunction(vtkDataArray id0,vtkDataArray id1)
    { EvaluateFunction_2(id0,id1); }

  private native double EvaluateFunction_3(double id0[]);
  public double EvaluateFunction(double id0[])
    { return EvaluateFunction_3(id0); }

  private native void EvaluateGradient_4(double id0[],double id1[]);
  public void EvaluateGradient(double id0[],double id1[])
    { EvaluateGradient_4(id0,id1); }

  private native void SetNormal_5(double id0,double id1,double id2);
  public void SetNormal(double id0,double id1,double id2)
    { SetNormal_5(id0,id1,id2); }

  private native void SetNormal_6(double id0[]);
  public void SetNormal(double id0[])
    { SetNormal_6(id0); }

  private native double[] GetNormal_7();
  public double[] GetNormal()
    { return GetNormal_7(); }

  private native void SetOrigin_8(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_8(id0,id1,id2); }

  private native void SetOrigin_9(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_9(id0); }

  private native double[] GetOrigin_10();
  public double[] GetOrigin()
    { return GetOrigin_10(); }

  private native void Push_11(double id0);
  public void Push(double id0)
    { Push_11(id0); }

  private native void ProjectPoint_12(double id0[],double id1[],double id2[],double id3[]);
  public void ProjectPoint(double id0[],double id1[],double id2[],double id3[])
    { ProjectPoint_12(id0,id1,id2,id3); }

  private native void ProjectPoint_13(double id0[],double id1[]);
  public void ProjectPoint(double id0[],double id1[])
    { ProjectPoint_13(id0,id1); }

  private native void ProjectVector_14(double id0[],double id1[],double id2[],double id3[]);
  public void ProjectVector(double id0[],double id1[],double id2[],double id3[])
    { ProjectVector_14(id0,id1,id2,id3); }

  private native void ProjectVector_15(double id0[],double id1[]);
  public void ProjectVector(double id0[],double id1[])
    { ProjectVector_15(id0,id1); }

  private native void GeneralizedProjectPoint_16(double id0[],double id1[],double id2[],double id3[]);
  public void GeneralizedProjectPoint(double id0[],double id1[],double id2[],double id3[])
    { GeneralizedProjectPoint_16(id0,id1,id2,id3); }

  private native void GeneralizedProjectPoint_17(double id0[],double id1[]);
  public void GeneralizedProjectPoint(double id0[],double id1[])
    { GeneralizedProjectPoint_17(id0,id1); }

  private native double Evaluate_18(double id0[],double id1[],double id2[]);
  public double Evaluate(double id0[],double id1[],double id2[])
    { return Evaluate_18(id0,id1,id2); }

  private native double DistanceToPlane_19(double id0[],double id1[],double id2[]);
  public double DistanceToPlane(double id0[],double id1[],double id2[])
    { return DistanceToPlane_19(id0,id1,id2); }

  private native double DistanceToPlane_20(double id0[]);
  public double DistanceToPlane(double id0[])
    { return DistanceToPlane_20(id0); }

  private native int IntersectWithFinitePlane_21(double id0[],double id1[],double id2[],double id3[],double id4[],double id5[],double id6[]);
  public int IntersectWithFinitePlane(double id0[],double id1[],double id2[],double id3[],double id4[],double id5[],double id6[])
    { return IntersectWithFinitePlane_21(id0,id1,id2,id3,id4,id5,id6); }

  private native int IntersectWithFinitePlane_22(double id0[],double id1[],double id2[],double id3[],double id4[]);
  public int IntersectWithFinitePlane(double id0[],double id1[],double id2[],double id3[],double id4[])
    { return IntersectWithFinitePlane_22(id0,id1,id2,id3,id4); }

  private native double EvaluateFunction_23(double id0,double id1,double id2);
  public double EvaluateFunction(double id0,double id1,double id2)
    { return EvaluateFunction_23(id0,id1,id2); }

  public vtkPlane() { super(); }

  public vtkPlane(long id) { super(id); }
  public native long   VTKInit();

}
